==> eis-insurance-1.44.0.tar.gz: eis-insurance-1.44.0/eis/insurance/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from eis.insurance.api.booking_funnel_versions_api import BookingFunnelVersionsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from eis.insurance.api.booking_funnel_versions_api import BookingFunnelVersionsApi
from eis.insurance.api.booking_funnels_api import BookingFunnelsApi
from eis.insurance.api.emil_functions_api import EmilFunctionsApi
from eis.insurance.api.insured_object_types_api import InsuredObjectTypesApi
from eis.insurance.api.insured_objects_api import InsuredObjectsApi
from eis.insurance.api.lead_statuses_api import LeadStatusesApi
from eis.insurance.api.lead_versions_api import LeadVersionsApi
from eis.insurance.api.leads_api import LeadsApi
from eis.insurance.api.named_ranges_api import NamedRangesApi
from eis.insurance.api.partner_links_api import PartnerLinksApi
from eis.insurance.api.partner_roles_api import PartnerRolesApi
from eis.insurance.api.policies_api import PoliciesApi
from eis.insurance.api.premium_formulas_api import PremiumFormulasApi
from eis.insurance.api.product_factors_api import ProductFactorsApi
from eis.insurance.api.product_fields_api import ProductFieldsApi
from eis.insurance.api.product_versions_api import ProductVersionsApi
from eis.insurance.api.products_api import ProductsApi
from eis.insurance.api.status_transition_rules_api import StatusTransitionRulesApi
from eis.insurance.api.default_api import DefaultApi

==> eis-insurance-1.51.0.tar.gz: eis-insurance-1.51.0/eis/insurance/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from eis.insurance.api.booking_funnel_versions_api import BookingFunnelVersionsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from eis.insurance.api.booking_funnel_versions_api import BookingFunnelVersionsApi
from eis.insurance.api.booking_funnels_api import BookingFunnelsApi
from eis.insurance.api.commission_agreement_products_api import CommissionAgreementProductsApi
from eis.insurance.api.commission_agreement_versions_api import CommissionAgreementVersionsApi
from eis.insurance.api.commission_agreements_api import CommissionAgreementsApi
from eis.insurance.api.commission_recipients_api import CommissionRecipientsApi
from eis.insurance.api.emil_functions_api import EmilFunctionsApi
from eis.insurance.api.health_check_api import HealthCheckApi
from eis.insurance.api.insured_object_types_api import InsuredObjectTypesApi
from eis.insurance.api.insured_objects_api import InsuredObjectsApi
from eis.insurance.api.lead_statuses_api import LeadStatusesApi
from eis.insurance.api.lead_versions_api import LeadVersionsApi
from eis.insurance.api.leads_api import LeadsApi
from eis.insurance.api.named_ranges_api import NamedRangesApi
from eis.insurance.api.partner_links_api import PartnerLinksApi
from eis.insurance.api.partner_roles_api import PartnerRolesApi
from eis.insurance.api.policies_api import PoliciesApi
from eis.insurance.api.premium_formulas_api import PremiumFormulasApi
from eis.insurance.api.product_factors_api import ProductFactorsApi
from eis.insurance.api.product_fields_api import ProductFieldsApi
from eis.insurance.api.product_versions_api import ProductVersionsApi
from eis.insurance.api.products_api import ProductsApi
from eis.insurance.api.status_transition_rules_api import StatusTransitionRulesApi
